==> rc-ui-lib-0.2.4.tgz: package/es/grid/GridItem.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
var _excluded = ["children", "className", "style"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useContext, useMemo } from 'react';
import classnames from 'classnames';
import { addUnit } from '../utils';
import { BORDER } from '../utils/constant';
import Badge from '../badge';
import Icon from '../icon';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';

var GridItem = function GridItem(_ref) {
  var children = _ref.children,
      className = _ref.className,
      style = _ref.style,
      props = _objectWithoutProperties(_ref, _excluded);

  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('grid-item', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var index = props.index,
      parent = props.parent;

  if (!parent) {
    if (process.env.NODE_ENV !== 'production') {
      // eslint-disable-next-line no-console
      console.error('[rc-ui-lib] <GridItem> must be a child component of <Grid>.');
    }
  }

  var rootStyle = useMemo(function () {
    var square = parent.square,
        gutter = parent.gutter,
        columnNum = parent.columnNum;
    var percent = "".concat(100 / +columnNum, "%");

    var internalStyle = _objectSpread(_objectSpread({}, style), {}, {
      flexBasis: percent
    });

    if (square) {
      internalStyle.paddingTop = percent;
    } else if (gutter) {
      var gutterValue = addUnit(gutter);
      internalStyle.paddingRight = gutterValue;

      if (index >= columnNum) {
        internalStyle.marginTop = gutterValue;
      }
    }

    return internalStyle;
  }, [parent.style, parent.gutter, parent.columnNum]);
  var contentStyle = useMemo(function () {
    var square = parent.square,
        gutter = parent.gutter;

    if (square && gutter) {
      var gutterValue = addUnit(gutter);
      return _objectSpread(_objectSpread({}, props.contentStyle), {}, {
        right: gutterValue,
        bottom: gutterValue,
        height: 'auto'
      });
    }

    return props.contentStyle;
  }, [parent.gutter, parent.columnNum, props.contentStyle]);

  var renderIcon = function renderIcon() {
    if (typeof props.icon === 'string') {
      return /*#__PURE__*/React.createElement(Icon, {
        badge: props.badge,
        name: props.icon,
        size: parent.iconSize,
        className: classnames(bem('icon')),
        classPrefix: props.iconPrefix,
        color: props.iconColor
      });
    }

    if ( /*#__PURE__*/React.isValidElement(props.icon)) {
      return /*#__PURE__*/React.createElement(Badge, props.badge, props.icon);
    }

    return null;
  };

  var renderText = function renderText() {
    if ( /*#__PURE__*/React.isValidElement(props.text)) {
      return props.text;
    }

    if (props.text) {
      return /*#__PURE__*/React.createElement("span", {
        className: classnames(bem('text'))
      }, props.text);
    }

    return null;
  };

  var renderContent = function renderContent() {
    if (children) {
      return children;
    }

    return /*#__PURE__*/React.createElement(React.Fragment, null, renderIcon(), renderText());
  };

  var center = parent.center,
      border = parent.border,
      square = parent.square,
      gutter = parent.gutter,
      reverse = parent.reverse,
      direction = parent.direction;
  var classes = classnames(props.contentClassName, bem('content', [direction, {
    center: center,
    square: square,
    reverse: reverse,
    clickable: !!props.onClick,
    surround: border && gutter
  }]), _defineProperty({}, BORDER, border));
  return /*#__PURE__*/React.createElement("div", {
    className: classnames(className, bem({
      square: square
    })),
    style: rootStyle
  }, /*#__PURE__*/React.createElement("div", {
    role: props.onClick ? 'button' : undefined,
    className: classes,
    style: contentStyle,
    onClick: props.onClick
  }, renderContent()));
};

GridItem.defaultProps = {
  index: 0,
  parent: {}
};
export default GridItem;

==> rc-ui-lib-1.3.4.tgz: package/es/grid/GridItem.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
var _excluded = ["children", "className", "style"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { useContext, useMemo } from 'react';
import classnames from 'classnames';
import { addUnit } from '../utils';
import { BORDER } from '../utils/constant';
import Badge from '../badge';
import Icon from '../icon';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';

var GridItem = function GridItem(_ref) {
  var children = _ref.children,
      className = _ref.className,
      style = _ref.style,
      props = _objectWithoutProperties(_ref, _excluded);

  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('grid-item', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var index = props.index,
      parent = props.parent;

  if (!parent) {
    if (process.env.NODE_ENV !== 'production') {
      // eslint-disable-next-line no-console
      console.error('[rc-ui-lib] <GridItem> must be a child component of <Grid>.');
    }
  }

  var rootStyle = useMemo(function () {
    var square = parent.square,
        gutter = parent.gutter,
        columnNum = parent.columnNum;
    var percent = "".concat(100 / +columnNum, "%");

    var internalStyle = _objectSpread(_objectSpread({}, style), {}, {
      flexBasis: percent
    });

    if (square) {
      internalStyle.paddingTop = percent;
    } else if (gutter) {
      var gutterValue = addUnit(gutter);
      internalStyle.paddingRight = gutterValue;

      if (index >= columnNum) {
        internalStyle.marginTop = gutterValue;
      }
    }

    return internalStyle;
  }, [parent.style, parent.gutter, parent.columnNum]);
  var contentStyle = useMemo(function () {
    var square = parent.square,
        gutter = parent.gutter;

    if (square && gutter) {
      var gutterValue = addUnit(gutter);
      return _objectSpread(_objectSpread({}, props.contentStyle), {}, {
        right: gutterValue,
        bottom: gutterValue,
        height: 'auto'
      });
    }

    return props.contentStyle;
  }, [parent.gutter, parent.columnNum, props.contentStyle]);

  var renderIcon = function renderIcon() {
    if (typeof props.icon === 'string') {
      return /*#__PURE__*/React.createElement(Icon, {
        badge: props.badge,
        name: props.icon,
        size: parent.iconSize,
        className: classnames(bem('icon')),
        classPrefix: props.iconPrefix,
        color: props.iconColor
      });
    }

    if ( /*#__PURE__*/React.isValidElement(props.icon)) {
      return /*#__PURE__*/React.createElement(Badge, props.badge, props.icon);
    }

    return null;
  };

  var renderText = function renderText() {
    if ( /*#__PURE__*/React.isValidElement(props.text)) {
      return props.text;
    }

    if (props.text) {
      return /*#__PURE__*/React.createElement("span", {
        className: classnames(bem('text'))
      }, props.text);
    }

    return null;
  };

  var renderContent = function renderContent() {
    if (children) {
      return children;
    }

    return /*#__PURE__*/React.createElement(React.Fragment, null, renderIcon(), renderText());
  };

  var center = parent.center,
      border = parent.border,
      square = parent.square,
      gutter = parent.gutter,
      reverse = parent.reverse,
      direction = parent.direction;
  var classes = classnames(props.contentClassName, bem('content', [direction, {
    center: center,
    square: square,
    reverse: reverse,
    clickable: !!props.onClick,
    surround: border && gutter
  }]), _defineProperty({}, BORDER, border));
  return /*#__PURE__*/React.createElement("div", {
    className: classnames(className, bem({
      square: square
    })),
    style: rootStyle
  }, /*#__PURE__*/React.createElement("div", {
    role: props.onClick ? 'button' : undefined,
    className: classes,
    style: contentStyle,
    onClick: props.onClick
  }, renderContent()));
};

GridItem.defaultProps = {
  index: 0,
  parent: {}
};
export default GridItem;
